pub struct Currency {
pub id: CurrencyId,
pub name: I18nString,
pub description: I18nString,
pub icon_url: String,
pub icon_path: String,
}Fields
id: CurrencyIdname: I18nStringdescription: I18nStringicon_url: Stringicon_path: StringTrait Implementations
Sourceimpl CustomType for Currency
impl CustomType for Currency
Sourcefn build(builder: TypeBuilder<'_, Self>)
fn build(builder: TypeBuilder<'_, Self>)
Builds the custom type for use with the [
Engine]. Read moreSourceimpl<'de> Deserialize<'de> for Currency
impl<'de> Deserialize<'de> for Currency
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Currency
impl JsonSchema for Currency
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Tsify for Currency
impl Tsify for Currency
const DECL: &'static str = "export interface Currency {\n id: CurrencyId;\n name: I18nString;\n description: I18nString;\n icon_url: string;\n icon_path: string;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for Currency
impl StructuralPartialEq for Currency