pub struct CurrencyUnit {
pub currency_id: CurrencyId,
pub amount: i64,
}Fields
currency_id: CurrencyIdamount: i64Trait Implementations
Sourceimpl Clone for CurrencyUnit
impl Clone for CurrencyUnit
Sourcefn clone(&self) -> CurrencyUnit
fn clone(&self) -> CurrencyUnit
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CustomType for CurrencyUnit
impl CustomType for CurrencyUnit
Sourcefn build(builder: TypeBuilder<'_, Self>)
fn build(builder: TypeBuilder<'_, Self>)
Builds the custom type for use with the [
Engine]. Read moreSourceimpl Debug for CurrencyUnit
impl Debug for CurrencyUnit
Sourceimpl Default for CurrencyUnit
impl Default for CurrencyUnit
Sourcefn default() -> CurrencyUnit
fn default() -> CurrencyUnit
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for CurrencyUnit
impl<'de> Deserialize<'de> for CurrencyUnit
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for CurrencyUnit
impl Hash for CurrencyUnit
Sourceimpl JsonSchema for CurrencyUnit
impl JsonSchema for CurrencyUnit
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Ord for CurrencyUnit
impl Ord for CurrencyUnit
Sourceimpl PartialEq for CurrencyUnit
impl PartialEq for CurrencyUnit
Sourceimpl PartialOrd for CurrencyUnit
impl PartialOrd for CurrencyUnit
Sourceimpl Serialize for CurrencyUnit
impl Serialize for CurrencyUnit
Sourceimpl Tsify for CurrencyUnit
impl Tsify for CurrencyUnit
const DECL: &'static str = "export interface CurrencyUnit {\n currency_id: CurrencyId;\n amount: number;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for CurrencyUnit
impl StructuralPartialEq for CurrencyUnit